=======
History
=======

0.1.5
-----

first release on pypi

0.1.4
-----

added read_data, read_all_data, and read_epw to easily parse data files

0.1.3
-----
added script_template and script_template2 for easy in directory coding

0.1.2
-----
wrote readme

0.1.0
-----
first stable release

0.0.1
-----
Initial setup of the directory

